@@ -2,4 +2,4 @@
 
 from .main import setup  # noqa
 from .asgi import turbulette_starlette  # noqa
-from .apps.base import query, mutation  # noqa
+from .apps.base import query, mutation, subscription  # noqa
