@@ -1,4 +1,6 @@
-from turbulette.errors import ErrorCode, BaseError
+"""Exceptions raised when encoding/decoding JWTs."""
+
+from turbulette.errors import BaseError, ErrorCode
 
 
 class JWTDecodeError(BaseError):
