@@ -1,6 +1,10 @@
-from typing import Optional
+"""Pydantic models to validate user and tokens."""
+
 from datetime import datetime as dt
+from typing import Optional
+
 from pydantic import BaseModel, EmailStr, root_validator
+
 from .core import get_password_hash
 
 
@@ -20,8 +24,8 @@ class TokenData(BaseModel):
 class BaseUserCreate(BaseModel):
     """Base User model.
 
-    The hashed_password shouldn't be supplied
-    has filled by the root validator if passwords matches
+    The `hashed_password` shouldn't be supplied
+    has it's filled by the root validator if passwords matches
     """
 
     username: str
@@ -39,7 +43,7 @@ class BaseUserCreate(BaseModel):
         return super().dict(exclude={"password_one", "password_two"}, **kwargs)
 
     @root_validator(pre=True)
-    def check_passwords_and_hash(cls, values):
+    def check_passwords_and_hash(cls, values):  # pylint: disable=no-self-argument
         """Hash the password if it's confirmed."""
         pw1, pw2 = values.get("password_one"), values.get("password_two")
         if pw1 and pw2 and pw1 != pw2:
