@@ -1,7 +1,10 @@
+"""The registry stores and manages Turbulette apps."""
+
 from importlib import import_module
 from inspect import ismodule
 from types import ModuleType
 from typing import Dict, List
+
 from ariadne import snake_case_fallback_resolvers
 from graphql.type import GraphQLSchema
 from simple_settings import LazySettings
@@ -18,10 +21,10 @@ from turbulette.conf.constants import (
     SETTINGS_RULES,
     TURBULETTE_CORE_APPS,
 )
+from turbulette.utils import get_project_settings
 from turbulette.validation import pydantic_binder
 
 from .app import TurbuletteApp
-from .config import get_project_settings_by_env
 from .constants import MODULE_SETTINGS
 from .exceptions import RegistryError
 
@@ -53,7 +56,7 @@ class Registry:
     """A class storing the Turbulette applications in use.
 
     It mostly serve as a proxy to execute common actions on all apps
-    plus some configuration stuff (loading settings etc)
+    plus some configuration stuff (loading settings, models etc)
     """
 
     def __init__(
@@ -66,12 +69,9 @@ class Registry:
         self.apps: Dict[str, TurbuletteApp] = {}
         self._ready = False
 
-        if project_settings:
-            project_settings_module = import_module(project_settings)
-
         project_settings_module = (
-            get_project_settings_by_env()
-            if project_settings_module is None
+            import_module(get_project_settings(project_settings))
+            if not project_settings_module
             else project_settings_module
         )
 
@@ -94,7 +94,7 @@ class Registry:
         """Retrieve the Turbulette app given its label.
 
         Args:
-            label (str): App label
+            label: App label
 
         Returns:
             TurbuletteApp: The Turbulette application
@@ -110,23 +110,23 @@ class Registry:
         """Retrieve a Turbulette application given its package path.
 
         Args:
-            path (str): The module path of the app (dotted path)
+            path: The module path of the app (dotted path)
 
         Returns:
-            GraphLQApp: The Turbulette application
+            TurbuletteApp: The Turbulette application
         """
         try:
             return self.apps[package_name.rsplit(".", maxsplit=1)[-1]]
         except KeyError as error:
             raise RegistryError(
-                f'App with package name "{package_name}" cannot be found in the registry'
+                f'App "{package_name}" cannot be found in the registry'
             ) from error
 
     def setup(self) -> GraphQLSchema:
-        """Load GraphQL resources and settings for each app and return the global executable schema.
+        """Load GraphQL resources, settings and create the global executable schema.
 
         Returns:
-            GraphQLSchema: The aggregated schema
+            GraphQLSchema: The aggregated schema from all apps
         """
         settings = self.load_settings()
         if settings.APOLLO_FEDERATION:
@@ -162,14 +162,17 @@ class Registry:
         return executable_schema
 
     def load_models(self):
-        """Import GINO models of each app."""
+        """Import GINO models of each app.
+
+        This make the GINO instance aware of all models across installed apps.
+        """
         for app in self.apps.values():
             app.load_models()
 
     def load_settings(self) -> LazySettings:
-        """Put Turbulette app settings together in a LazySettings object.
+        """Put Turbulette app settings together in a `LazySettings` object.
 
-        The LazySettings object is from ``simple_settings`` library, which accepts
+        The `LazySettings` object is from `simple_settings` library, which accepts
         multiple modules path during instantiation.
 
         Returns:
@@ -187,7 +190,9 @@ class Registry:
             all_settings.append(self.project_settings_path)
 
             settings = LazySettings(*all_settings)
-            settings._dict["SIMPLE_SETTINGS"] = conf.SIMPLE_SETTINGS
+            settings._dict[  # pylint: disable=protected-access
+                "SIMPLE_SETTINGS"
+            ] = conf.SIMPLE_SETTINGS
             settings.strategies = (TurbuletteSettingsLoadStrategy,)
             # Make settings variable availble in the `turbulette.conf` package
             conf.settings = settings
@@ -196,6 +201,14 @@ class Registry:
         return conf.settings
 
     def register(self, app: TurbuletteApp):
+        """Register an existing [TurbuletteApp][turbulette.apps.app:TurbuletteApp].
+
+        Args:
+            app: The [TurbuletteApp][turbulette.apps.app:TurbuletteApp] to add
+
+        Raises:
+            RegistryError: Raised if the app is already registered
+        """
         if app.label in self.apps:
             raise RegistryError(f'App "{app}" is already registered')
         self.apps[app.label] = app
