@@ -1,3 +1,5 @@
+"""Global names for modules, settings and files."""
+
 # Locations
 PROJECT_SETTINGS_MODULE = "TURBULETTE_SETTINGS_MODULE"
 
@@ -26,9 +28,8 @@ FOLDER_MIGRATIONS = "migrations"
 # Apps that must always be loaded with turbulette
 TURBULETTE_CORE_APPS = ["turbulette.apps.base"]
 
-
-# pytest settings
-PYTEST_TURBULETTE_SETTINGS = "PYTEST_TURBULETTE_SETTINGS"
-
 TURBULETTE_ROUTING_MODULE = "routing"
 ROUTING_MODULE_ROUTES = "routes"
+
+# Tests
+TEST_MODE = "TURBULETTE_PYTEST"
