@@ -1,17 +1,21 @@
+"""Interact with the alembic API to run migrations."""
+
 import sys
-from os import environ
 from importlib import import_module
 from logging.config import fileConfig
 from pathlib import Path
+from typing import Optional
+
 from alembic import context
 from sqlalchemy import engine_from_config, pool
+
+from turbulette import conf
 from turbulette.apps import Registry
 from turbulette.main import get_gino_instance
-from turbulette import conf
-from turbulette.conf.constants import PROJECT_SETTINGS_MODULE
+from turbulette.utils import get_project_settings
 
 
-def run_migrations_offline(metadata, config):  # pragma: no cover
+def _run_migrations_offline(metadata, config):  # pragma: no cover
     """Run migrations in 'offline' mode.
 
     This configures the context with just a URL
@@ -35,7 +39,7 @@ def run_migrations_offline(metadata, config):  # pragma: no cover
         context.run_migrations()
 
 
-def run_migrations_online(metadata, config):  # pragma: no cover
+def _run_migrations_online(metadata, config):  # pragma: no cover
     """Run migrations in 'online' mode.
 
     In this scenario we need to create an Engine
@@ -55,11 +59,13 @@ def run_migrations_online(metadata, config):  # pragma: no cover
             context.run_migrations()
 
 
-def run_migrations():
+def run_migrations(project_settings: Optional[str] = None):
+    """Apply migrations for installed apps depending on the context (online/offline)."""
     # Add project folder to python path
     sys.path[0:0] = [str(Path.cwd().parent.resolve()), str(Path.cwd().resolve())]
 
-    settings = import_module(environ[PROJECT_SETTINGS_MODULE])
+    settings = import_module(get_project_settings(project_settings))
+
     registry = Registry(project_settings_module=settings)
     if not conf.registry.__initialized__:
         conf.registry.__setup__(registry)
@@ -79,9 +85,11 @@ def run_migrations():
     # for 'autogenerate' support
     metadata = database
     registry.load_models()
-    alembic_config.set_main_option("sqlalchemy.url", str(settings.DB_DSN))  # type: ignore
+    alembic_config.set_main_option(
+        "sqlalchemy.url", str(settings.DB_DSN)  # type: ignore
+    )
 
     if context.is_offline_mode():  # pragma: no cover
-        run_migrations_offline(metadata, alembic_config)
+        _run_migrations_offline(metadata, alembic_config)
     else:
-        run_migrations_online(metadata, alembic_config)
+        _run_migrations_online(metadata, alembic_config)
