@@ -1,5 +1,11 @@
+"""Project settings.
+
+These settings overrides the defaults ones set by Turbulette.
+"""
+
 from sqlalchemy.engine.url import URL, make_url
-from starlette.datastructures import Secret, CommaSeparatedStrings
+from starlette.datastructures import CommaSeparatedStrings, Secret
+
 from turbulette.conf import get_config_from_paths
 
 config = get_config_from_paths(["{{ project }}/.env", ".env"])
@@ -12,7 +18,7 @@ GRAPHQL_ENDPOINT = config("GRAPHQL_ENDPOINT", cast=str, default="/graphql")
 
 # List installed Turbulette apps
 # that defines some GraphQL schema
-INSTALLED_APPS: list = []
+INSTALLED_APPS = config("INSTALLED_APPS", cast=CommaSeparatedStrings, default=[])
 
 MIDDLEWARES = config("MIDDLEWARES", cast=CommaSeparatedStrings, default=[])
 
